"use strict";(self.webpackChunk_adhadse_theme_material_darcula=self.webpackChunk_adhadse_theme_material_darcula||[]).push([[568],{568:(e,a,t)=>{Object.defineProperty(a,"__esModule",{value:!0});const r={id:"@adhadse/theme-material-darcula:plugin",requires:[t(118).IThemeManager],activate:function(e,a){a.register({name:"Material Darcula",isLight:!1,themeScrollbars:!0,load:()=>a.loadCSS("@adhadse/theme-material-darcula/index.css"),unload:()=>Promise.resolve(void 0)})},autoStart:!0};a.default=r}}]);