/*-----------------------------------------------------------------------------
| Copyright (c) Max Klein.
| Copyright (c) Anurag Dhadse.
| Distributed under the terms of the Modified BSD License.
|----------------------------------------------------------------------------*/

@import "./codemirror-darcula.css";
@import "./variables.css";
@import "./base.css";
@import "./tabs.css";

/* Set the default typography for monospace elements */
tt,
code,
kbd,
samp,
pre {
  font-family: var(--jp-code-font-family);
  font-size: var(--jp-code-font-size);
  line-height: var(--jp-code-line-height);
}
