/*-----------------------------------------------------------------------------
| Copyright (c) Max Klein.
| Copyright (c) Anurag Dhadse.
| Distributed under the terms of the Modified BSD License.
|----------------------------------------------------------------------------*/

/*
 * Codemirror styling that isn't currently supported by Jupyterlab themes
 */

.cm-s-jupyter .CodeMirror-activeline-background {
  background: #323232;
}
.cm-s-jupyter .CodeMirror-guttermarker {
  color: #ffee80;
}
.cm-s-jupyter .CodeMirror-guttermarker-subtle {
  color: #d0d0d0;
}
.cm-s-jupyter .CodeMirror-linenumber {
  color: #606366;
}
.cm-s-jupyter .CodeMirror-matchingbracket {
  background-color: #3b514d;
  color: #ffef28 !important;
  font-weight: bold;
}

.cm-s-jupyter div.CodeMirror-selected {
  background: #214283;
}

.cm-s-jupyter span.cm-type {
  color: #aabbcc;
  font-weight: bold;
}

/*
.cm-s-jupyter span.cm-keyword    { color: #CC7832; line-height: 1em; font-weight: bold; }
.cm-s-jupyter span.cm-atom       { color: #CC7832; }
.cm-s-jupyter span.cm-number     { color: #6897BB; }
.cm-s-jupyter span.cm-def        { color: #A9B7C6; font-style: italic; }
.cm-s-jupyter span.cm-variable   { color: #A9B7C6; }
.cm-s-jupyter span.cm-variable-2 { color: #A9B7C6; }
.cm-s-jupyter span.cm-variable-3 { color: #9876AA; }
.cm-s-jupyter span.cm-special    { color: #FF9E59; }
.cm-s-jupyter span.cm-property   { color: #FFC66D; }
.cm-s-jupyter span.cm-operator   { color: #A9B7C6; }
.cm-s-jupyter span.cm-comment    { color: #61A151; font-style: italic; }
.cm-s-jupyter span.cm-string     { color: #6A8759; }
.cm-s-jupyter span.cm-string-2   { color: #6A8759; }
.cm-s-jupyter span.cm-meta       { color: #BBB529; }
.cm-s-jupyter span.cm-qualifier  { color: #6A8759; }
.cm-s-jupyter span.cm-builtin    { color: #FF9E59; }
.cm-s-jupyter span.cm-bracket    { color: #A9B7C6; }
.cm-s-jupyter span.cm-tag        { color: #629755; font-weight: bold; font-style: italic; text-decoration: underline; }
.cm-s-jupyter span.cm-attribute  { color: #6897bb; }

.cm-s-jupyter span.cm-link      { color: #CC7832; }
.cm-s-jupyter span.cm-error     { color: #BC3F3C; }

.cm-s-jupyter .CodeMirror-gutters { background: #313335; border-right: 1px solid #313335; }

.cm-s-jupyter  { font-family: Consolas, Menlo, Monaco, 'Lucida Console', 'Liberation Mono', 'DejaVu Sans Mono', 'Bitstream Vera Sans Mono', 'Courier New', monospace, serif;}
.cm-s-jupyter.CodeMirror { background: #2B2B2B; color: #A9B7C6; }

.CodeMirror-hints.jupyter {
    font-family: Menlo, Monaco, Consolas, 'Courier New', monospace;
    color: #9C9E9E;
    background-color: #3B3E3F !important;
}

.CodeMirror-hints.jupyter .CodeMirror-hint-active {
    background-color: #494D4E !important;
    color: #9C9E9E !important;
}
*/
